/*
                Sun Public License Notice

The contents of this file are subject to the Sun Public License
Version 1.0 (the "License"). You may not use this file except in
compliance with the License. A copy of the License is available at
http://www.sun.com/

The Original Code is NetBeans. The Initial Developer of the Original
Code is Sun Microsystems, Inc. Portions Copyright 1997-2004 Sun
Microsystems, Inc. All Rights Reserved.
*/
package org.netbeans.modules.snipe;

import org.openide.cookies.SaveCookie;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiDataObject;
import org.openide.loaders.MultiFileLoader;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.NbBundle;

/** 
 * Represents a Snipe file.
 *
 * @author  Rich Unger
 */
public class SnipeDataObject extends MultiDataObject {
    private SaveCookie m_saveCookie;
    
    public SnipeDataObject(FileObject fObj, MultiFileLoader loader) 
            throws DataObjectExistsException {
        super (fObj, loader);
        m_saveCookie = new SnipeSaveCookie(this);
        
        // add support for viewing a prompt in the IDE
        getCookieSet().add(new SnipeOpenSupport(getPrimaryEntry()));
    }
    
    /** Override DataObject. */
    public void setModified(boolean bModified) {
        if (bModified) {
            addSaveCookie();
        } else {
            removeSaveCookie();
        }
        super.setModified(bModified);
    }
    
    public HelpCtx getHelpCtx () {
        return HelpCtx.DEFAULT_HELP;
        // If you add context help, change to:
        // return new HelpCtx (MyDataObject.class);
    }

    protected Node createNodeDelegate () {
        return new SnipeNode(this);
    }

    private void addSaveCookie()
    {
        if( getCookie( SaveCookie.class ) == null ) {
            getCookieSet().add( m_saveCookie );
        }
    }

    private void removeSaveCookie()
    {
        SaveCookie save = (SaveCookie) getCookie( SaveCookie.class );
        if( save != null ) {
            getCookieSet().remove( save );
        }
    }
    
    private static final long serialVersionUID = 6338889116068357651L;
}
