package com.tomwheeler.stocktrader.ui.renderer;

import java.awt.Component;
import java.text.NumberFormat;

import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;

import org.openide.util.NbBundle;

/**
 * <p>
 * This class provides a table cell renderer that formats the value as
 * currency using the default locale.  There is nothing specific to NetBeans 
 * in this class except for how resource bundle values are looked up.
 * </p> 
 * 
 * @author Tom Wheeler
 */
public class CurrencyCellRenderer  extends JLabel implements TableCellRenderer {

    private static NumberFormat currencyFormatter = NumberFormat.getCurrencyInstance();
    
    public CurrencyCellRenderer() {
        super();
        setOpaque(true);
    }
    
    /* (non-Javadoc)
     * @see javax.swing.table.TableCellRenderer#getTableCellRendererComponent(javax.swing.JTable, java.lang.Object, boolean, boolean, int, int)
     */
    public Component getTableCellRendererComponent(JTable table, Object value,
            boolean isSelected, boolean hasFocus, int row, int column) {
        
        setBackground(isSelected ? table.getSelectionBackground() : table.getBackground());
        setForeground(isSelected ? table.getSelectionForeground() : table.getForeground());
        setFont(table.getFont());
        
        if (value == null) {
            String text = NbBundle.getMessage(CurrencyCellRenderer.class, "LBL_CurrencyPriceNA");
            setText(text);
        } else {
            setText(currencyFormatter.format(value));
        }

        return this;
    }

}
