package com.tomwheeler.stocktrader.ui.renderer;

import java.awt.Color;
import java.awt.Component;
import java.text.NumberFormat;

import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;

import org.openide.util.NbBundle;

/**
 * <p>
 * This class provides a table cell renderer that can display numbers.
 * The foreground color used depends on whether the value is positive, 
 * negative or zero, and the number is formatted as a percent according
 * to the default locale.  There is nothing specific to NetBeans in this
 * class except for how resource bundle values are looked up.
 * </p> 
 * 
 * @author Tom Wheeler
 */
public class PercentChangeCellRenderer extends JLabel implements TableCellRenderer {
    
    private static NumberFormat percentFormatter = NumberFormat.getPercentInstance();
    static {
        percentFormatter.setMaximumFractionDigits(2);    
    }
    
    public PercentChangeCellRenderer() {
        super();
        setOpaque(true);
    }
    
    /* (non-Javadoc)
     * @see javax.swing.table.TableCellRenderer#getTableCellRendererComponent(javax.swing.JTable, java.lang.Object, boolean, boolean, int, int)
     */
    public Component getTableCellRendererComponent(JTable table, Object value,
            boolean isSelected, boolean hasFocus, int row, int column) {

        setBackground(isSelected ? table.getSelectionBackground() : table.getBackground());
        setFont(table.getFont());

        if (value == null) {
            String text = NbBundle.getMessage(CurrencyCellRenderer.class, "LBL_PercentChangeNA");
            setText(text);
        } else {
            double percent = ((Number)value).doubleValue();
            // TODO lookup color choices from NetBeans settings
            if (percent > 0) {
                setForeground(Color.GREEN);    
            } else if (percent < 0) {
                setForeground(Color.RED);
            } else {
                setForeground(Color.BLACK);
            }
            setText(percentFormatter.format(percent));
        }
        
        return this;
    }
}
